@@ -1,6 +1,10 @@
 import re
-from gql.client import SyncClientSession
-from specklepy.logging.exceptions import SpeckleException
+from warnings import warn
+from specklepy.logging.exceptions import (
+    GraphQLException,
+    SpeckleException,
+    SpeckleWarning,
+)
 from typing import Dict
 
 from specklepy.api import resources
@@ -14,9 +18,8 @@ from specklepy.api.resources import (
     subscriptions,
 )
 from specklepy.api.models import ServerInfo
-from gql import Client, gql
+from gql import Client
 from gql.transport.requests import RequestsHTTPTransport
-from gql.transport.aiohttp import AIOHTTPTransport
 from gql.transport.websockets import WebsocketsTransport
 
 
@@ -77,6 +80,8 @@ class SpeckleClient:
         # Check compatibility with the server
         try:
             serverInfo = self.server.get()
+            if isinstance(serverInfo, Exception):
+                raise serverInfo
             if not isinstance(serverInfo, ServerInfo):
                 raise Exception("Couldn't get ServerInfo")
         except Exception as ex:
@@ -111,6 +116,13 @@ class SpeckleClient:
 
         self._init_resources()
 
+        if isinstance(self.user.get(), GraphQLException):
+            warn(
+                SpeckleWarning(
+                    f"Invalid token - could not authenticate Speckle Client for server {self.url}"
+                )
+            )
+
     def execute_query(self, query: str) -> Dict:
         return self.httpclient.execute(query)
 
